@@ -19,7 +19,8 @@ typedef enum {
     CGREEN_RETURN_POINTER_CONSTRAINT,
     CGREEN_CALL_CONSTRAINT,
     CGREEN_CALL_COUNTER_CONSTRAINT,
-    CGREEN_RETURN_BY_VALUE_CONSTRAINT
+    CGREEN_RETURN_BY_VALUE_CONSTRAINT,
+    CGREEN_CAPTURE_PARAMETER_CONSTRAINT
 } ConstraintType;
 
 typedef struct Constraint_ Constraint;
@@ -87,6 +88,7 @@ Constraint *create_return_by_value_constraint(intptr_t value_to_return, size_t s
 Constraint *create_return_double_value_constraint(double value_to_return);
 Constraint *create_set_parameter_value_constraint(const char *parameter_name, intptr_t value_to_set, size_t size_to_set);
 Constraint *create_with_side_effect_constraint(void (*callback)(void *), void *data);
+Constraint *create_capture_parameter_constraint(const char *parameter_name, void *captured, size_t size_to_capture);
 
 #ifdef __cplusplus
     }
