@@ -3,6 +3,7 @@
 
 #include "internal/suite_internal.h"
 
+#include <cgreen/filename.h>
 #include <cgreen/reporter.h>
 #include <cgreen/unit.h>
 #include <cgreen/internal/function_macro.h>
@@ -16,8 +17,8 @@ namespace cgreen {
     extern "C" {
 #endif
 
-#define create_test_suite() create_named_test_suite_(__func__, __FILE__, __LINE__)
-#define create_named_test_suite(name) create_named_test_suite_(name, __FILE__, __LINE__)
+#define create_test_suite() create_named_test_suite_(__func__, FILENAME, __LINE__)
+#define create_named_test_suite(name) create_named_test_suite_(name, FILENAME, __LINE__)
 #define add_test(suite, test) add_test_(suite, STRINGIFY_TOKEN(test), &spec_name(default, test))
 #define add_test_with_context(suite, context, test) add_test_(suite, STRINGIFY_TOKEN(test), &spec_name(context, test))
 #define add_tests(suite, ...) add_tests_(suite, #__VA_ARGS__, (CgreenTest *)__VA_ARGS__)
