@@ -14,6 +14,7 @@
 #include "parameters.h"
 #include "constraint_internal.h"
 #include "utils.h"
+#include "runner.h"
 
 
 #ifdef __ANDROID__
@@ -187,7 +188,6 @@ intptr_t mock_(TestReporter* test_reporter, const char *function, const char *mo
     CgreenVector *parameter_names;
     int failures_before_read_only_constraints_executed;
     int failures_after_read_only_constraints_executed;
-    int i;
     CgreenValue stored_result;
     RecordedExpectation *expectation = find_expectation(function);
 
@@ -222,15 +222,11 @@ intptr_t mock_(TestReporter* test_reporter, const char *function, const char *mo
     // return them. There should also be a 'mock_double_()' which does the same except
     // returning a double.
 
-    for (i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
+    // First check all actual constraints for validity...
+    for (int i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
         Constraint *constraint = (Constraint *)cgreen_vector_get(expectation->constraints, i);
 
-        if (is_side_effect_constraint(constraint)) {
-            apply_side_effect(test_reporter, expectation, constraint);
-            continue;
-        }
-
-        if(constraint->type == CGREEN_CALL_COUNTER_CONSTRAINT) {
+        if (constraint->type == CGREEN_CALL_COUNTER_CONSTRAINT) {
             expectation->number_times_called++;
             continue;
         }
@@ -250,11 +246,13 @@ intptr_t mock_(TestReporter* test_reporter, const char *function, const char *mo
         }
     }
 
-    // if read-only constraints aren't matching, content-setting ones might corrupt memory
-    // so apply read-only ones first, and if they don't fail, then do the deeper constraints
+    // Now we can do the read-only constraints.  If read-only
+    // constraints aren't matching, content-setting ones might corrupt
+    // memory so apply read-only ones first, and if they don't fail,
+    // then do the deeper constraints
     failures_before_read_only_constraints_executed = test_reporter->failures;
 
-    for (i = 0; i < cgreen_vector_size(parameter_names); i++) {
+    for (int i = 0; i < cgreen_vector_size(parameter_names); i++) {
         const char* parameter_name = (const char*)cgreen_vector_get(parameter_names, i);
         CgreenValue actual = *(CgreenValue*)cgreen_vector_get(actual_values, i);
         apply_any_read_only_parameter_constraints(expectation, parameter_name, actual, test_reporter);
@@ -262,17 +260,30 @@ intptr_t mock_(TestReporter* test_reporter, const char *function, const char *mo
 
     failures_after_read_only_constraints_executed = test_reporter->failures;
 
+    // And now we can do the content setting constraints...
     // FIXME: this comparison doesn't work because only parent
     //        processes' pass/fail counts are updated, and even then
     //        only once they read from the pipe
     if (failures_before_read_only_constraints_executed == failures_after_read_only_constraints_executed) {
-        for (i = 0; i < cgreen_vector_size(parameter_names); i++) {
+        for (int i = 0; i < cgreen_vector_size(parameter_names); i++) {
             const char* parameter_name = (const char*)cgreen_vector_get(parameter_names, i);
             CgreenValue actual = *(CgreenValue*)cgreen_vector_get(actual_values, i);
             apply_any_content_setting_parameter_constraints(expectation, parameter_name, actual, test_reporter);
         }
     }
 
+    // And finally run all side effects
+    for (int i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
+        Constraint *constraint = (Constraint *)cgreen_vector_get(expectation->constraints, i);
+
+        if (is_side_effect_constraint(constraint)) {
+            apply_side_effect(test_reporter, expectation, constraint);
+            continue;
+        }
+    }
+
+
+
     destroy_cgreen_vector(parameter_names);
     destroy_cgreen_vector(actual_values);
 
@@ -602,8 +613,8 @@ static void report_unexpected_call(TestReporter *test_reporter, RecordedExpectat
 
     test_reporter->assert_true(
         test_reporter,
-        expectation->test_file,
-        expectation->test_line,
+        current_test->filename,
+        current_test->line,
         false,
         message,
         expectation->function);
@@ -790,7 +801,7 @@ static void trigger_unfulfilled_expectations(CgreenVector *expectation_queue, Te
         bool call_counter_present = false;
         for (int c = 0; c < cgreen_vector_size(expectation->constraints); c++) {
             Constraint *constraint = (Constraint *) cgreen_vector_get(expectation->constraints, c);
-            if(constraint->type == CGREEN_CALL_COUNTER_CONSTRAINT) {
+            if (constraint->type == CGREEN_CALL_COUNTER_CONSTRAINT) {
                 constraint->execute(
                         constraint,
                         expectation->function,
@@ -846,7 +857,7 @@ static void apply_any_read_only_parameter_constraints(RecordedExpectation *expec
     for (i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
         Constraint *constraint = (Constraint *)cgreen_vector_get(expectation->constraints, i);
 
-        if (is_content_setting(constraint)) {
+        if (is_content_setting(constraint) || is_side_effect_constraint(constraint)) {
             continue;
         }
 
@@ -867,9 +878,10 @@ static void apply_any_read_only_parameter_constraints(RecordedExpectation *expec
     }
 }
 
-static void apply_any_content_setting_parameter_constraints(RecordedExpectation *expectation, const char *parameter, CgreenValue actual, TestReporter* test_reporter) {
-    int i;
-    for (i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
+static void apply_any_content_setting_parameter_constraints(RecordedExpectation *expectation,
+                                                            const char *parameter, CgreenValue actual,
+                                                            TestReporter* test_reporter) {
+    for (int i = 0; i < cgreen_vector_size(expectation->constraints); i++) {
         Constraint *constraint = (Constraint *)cgreen_vector_get(expectation->constraints, i);
 
         if (constraint_is_not_for_parameter(constraint, parameter)) {
@@ -891,8 +903,7 @@ static void apply_any_content_setting_parameter_constraints(RecordedExpectation
 }
 
 static CgreenValue stored_result_or_default_for(CgreenVector* constraints) {
-    int i;
-    for (i = 0; i < cgreen_vector_size(constraints); i++) {
+    for (int i = 0; i < cgreen_vector_size(constraints); i++) {
         Constraint *constraint = (Constraint *)cgreen_vector_get(constraints, i);
 
         switch (constraint->type) {
@@ -922,8 +933,7 @@ static bool is_always_call(RecordedExpectation* expectation) {
 }
 
 static bool have_always_expectation_for(const char* function) {
-    int i;
-    for (i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
+    for (int i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
         RecordedExpectation *expectation =
                 (RecordedExpectation *)cgreen_vector_get(global_expectation_queue, i);
         if (strcmp(expectation->function, function) == 0) {
@@ -941,8 +951,7 @@ static bool is_never_call(RecordedExpectation* expectation) {
 }
 
 static bool have_never_call_expectation_for(const char* function) {
-    int i;
-    for (i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
+    for (int i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
         RecordedExpectation *expectation =
                 (RecordedExpectation *)cgreen_vector_get(global_expectation_queue, i);
         if (strcmp(expectation->function, function) == 0) {
@@ -956,8 +965,7 @@ static bool have_never_call_expectation_for(const char* function) {
 }
 
 static bool remove_never_call_expectation_for(const char* function) {
-    int i;
-    for (i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
+    for (int i = 0; i < cgreen_vector_size(global_expectation_queue); i++) {
         RecordedExpectation *expectation =
                 (RecordedExpectation *)cgreen_vector_get(global_expectation_queue, i);
         if (strcmp(expectation->function, function) == 0) {
