@@ -124,6 +124,47 @@ Ensure(Constraint, matching_strings_as_equal) {
     destroy_constraint(equals_string_hello_constraint);
 }
 
+Ensure(Constraint, matching_beginning_of_string) {
+    Constraint *beginning_of_string_hello_constraint =
+        create_begins_with_string_constraint("Hell", "user_greeting");
+
+    assert_that(compare_string_constraint(beginning_of_string_hello_constraint, "Hello"), is_true);
+    assert_that(compare_string_constraint(beginning_of_string_hello_constraint, "Goodbye"), is_false);
+
+    destroy_constraint(beginning_of_string_hello_constraint);
+}
+
+Ensure(Constraint, not_matching_beginning_of_string) {
+    Constraint *beginning_of_string_hello_constraint =
+        create_does_not_begin_with_string_constraint("Goodby", "user_greeting");
+
+    assert_that(compare_string_constraint(beginning_of_string_hello_constraint, "Hello"), is_true);
+    assert_that(compare_string_constraint(beginning_of_string_hello_constraint, "Goodbye"), is_false);
+
+    destroy_constraint(beginning_of_string_hello_constraint);
+}
+
+Ensure(Constraint, matching_end_of_string) {
+    Constraint *end_of_string_hello_constraint =
+        create_ends_with_string_constraint("ello", "user_greeting");
+
+    assert_that(compare_string_constraint(end_of_string_hello_constraint, "Hello"), is_true);
+    assert_that(compare_string_constraint(end_of_string_hello_constraint, "Goodbye"), is_false);
+    assert_that(compare_string_constraint(end_of_string_hello_constraint, "Hello ello"), is_true);
+
+    destroy_constraint(end_of_string_hello_constraint);
+}
+
+Ensure(Constraint, not_matching_end_of_string) {
+    Constraint *end_of_string_hello_constraint =
+        create_does_not_end_with_string_constraint("oodbye", "user_greeting");
+
+    assert_that(compare_string_constraint(end_of_string_hello_constraint, "Hello"), is_true);
+    assert_that(compare_string_constraint(end_of_string_hello_constraint, "Goodbye"), is_false);
+
+    destroy_constraint(end_of_string_hello_constraint);
+}
+
 Ensure(Constraint, matching_null_string_against_non_null_string) {
     Constraint *equals_string_hello_constraint =
             create_equal_to_string_constraint("Hello", "user_greeting");
@@ -243,14 +284,19 @@ TestSuite *constraint_tests(void) {
     TestSuite *suite = create_test_suite();
     add_test_with_context(suite, Constraint, default_destroy_clears_state);
     add_test_with_context(suite, Constraint, parameter_name_matches_correctly);
+    add_test_with_context(suite, Constraint, compare_contents_is_correct_on_larger_than_intptr_array);
     add_test_with_context(suite, Constraint, compare_is_correct_when_using_integers);
+    add_test_with_context(suite, Constraint, compare_to_is_null_correctly);
     add_test_with_context(suite, Constraint, string_constraint_destroy_clears_state);
     add_test_with_context(suite, Constraint, matching_strings_as_equal);
+    add_test_with_context(suite, Constraint, matching_beginning_of_string);
+    add_test_with_context(suite, Constraint, not_matching_beginning_of_string);
+    add_test_with_context(suite, Constraint, matching_end_of_string);
+    add_test_with_context(suite, Constraint, not_matching_end_of_string);
     add_test_with_context(suite, Constraint, matching_null_string_against_non_null_string);
     add_test_with_context(suite, Constraint, matching_against_null_string);
     add_test_with_context(suite, Constraint, matching_doubles_as_equal_with_default_significance);
     add_test_with_context(suite, Constraint, matching_doubles_respects_significant_figure_setting);
-    add_test_with_context(suite, Constraint, compare_contents_is_correct_on_larger_than_intptr_array);
     add_test_with_context(suite, Constraint, compare_equal_to_contents_is_false_on_null);
     add_test_with_context(suite, Constraint, compare_not_equal_to_contents_is_false_on_null);
     add_test_with_context(suite, Constraint, can_compare_to_hex);
